@@ -1,9 +1,8 @@
 import importlib
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 lib = 'epaper.e-Paper.RaspberryPi_JetsonNano.python.lib.waveshare_epd'
 
 def epaper(model):
-  return importlib.import_module('{}.{}'.format(lib, model)
-
+  return importlib.import_module('{}.{}'.format(lib, model))
